[![PyPI version](https://badge.fury.io/py/element-animal.svg)](http://badge.fury.io/py/element-animal)

# Element Animal

DataJoint Element for storing animal meta data, genotype, and surgery information.
DataJoint Elements collectively standardize and automate data collection and analysis
for neuroscience experiments. Each Element is a modular pipeline for data storage and
processing with corresponding database tables that can be combined with other Elements
to assemble a fully functional pipeline.

Installation and usage instructions can be found at the [Element documentation](https://datajoint.com/docs/elements/element-animal).

![Subect schema diagram](https://raw.githubusercontent.com/datajoint/element-animal/main/images/subject_diagram.svg)

![Genotyping schema diagram](https://raw.githubusercontent.com/datajoint/element-animal/main/images/genotyping_diagram.svg)

![Surgery schema diagram](https://raw.githubusercontent.com/datajoint/element-animal/main/images/surgery_diagram.svg)
